@@ -671,9 +671,6 @@ define([
         /** if for try 일 경우 */
         if ( IsIfForTryBlockType(blockType) == true
             && lastChildBlock != null) {
-            // console.log('lastChildBlock',lastChildBlock);
-            // console.log('_lastChildBlock',_lastChildBlock);
-            // console.log('childLowerDepthBlockList',childLowerDepthBlockList);
             var { elifList, 
                   lastChildBlock: _lastChildBlock } = lastChildBlock.getElifBlockList(childLowerDepthBlockList, stack);
         
@@ -691,7 +688,6 @@ define([
 
         /** if for try가 아닐 경우 */
         } else {
-            // console.log('childLowerDepthBlockList',childLowerDepthBlockList);
             childLowerDepthBlockList = this._getThisToLastBlockList(childLowerDepthBlockList, stack);
             this.setLastBlock_from_nodeBlockArea(lastChildBlock);
             return childLowerDepthBlockList;
@@ -716,11 +712,6 @@ define([
      * @return {Array<Block>}
      */
     Block.prototype.getElifBlockList = function() {
-        // console.log('_elifList', _elifList);
-        // console.log('_stack', _stack);
-        // var stack = _stack;
-        // console.log('stack', stack);
-
         var lastChildBlock = null;
         var return_BlockList = [];
         var _childBlockList = this.getChildBlockList();
@@ -731,7 +722,6 @@ define([
         var current;
         while (stack.length != 0) {
             current = stack.shift();
-            // console.log('current',current);
             /** FIXME: 무한루프 체크 */
             if (iteration > NUM_MAX_ITERATION) {
                 console.log(ERROR_AB0002_INFINITE_LOOP);
@@ -1153,25 +1143,26 @@ define([
             }
 
             case BLOCK_CODELINE_TYPE.API: {
+                // console.log('isRun',isRun);
                 vpCommon.setIsAPIListRunCode(isRun);
 
                 /** API List Pakage가 없을 때 */
                 if (!thisBlock.getImportPakage()) {
                     return 'BREAK_RUN';
                 }
-
-                var generatedCode = thisBlock.getImportPakage().generateCode(false, false);
-
+                var apiListPackage = thisBlock.getImportPakage();
+                var generatedCode = apiListPackage.generateCode(false, false);
+                var apicode = '';
                 /** API List 에서 generatedCode가 없을 때 */
                 if (!generatedCode) {
                     generatedCode = '';
-                }
-                console.log('generatedCode',generatedCode);
-                var apicode = MapNewLineStrToIndentString( generatedCode, 
+                } else {
+                    apicode = MapNewLineStrToIndentString( generatedCode, 
                                                            indentString);
+                }
  
-                thisBlock.getImportPakage().metaSave();   
-                thisBlock.getImportPakage().metaGenerate(); 
+                apiListPackage.metaSave();   
+                apiListPackage.metaGenerate(); 
 
                 /** API List 에서 BREAK_RUN을 리턴할 때 */
                 if (apicode.indexOf('BREAK_RUN') != -1) {
@@ -1397,7 +1388,6 @@ define([
         this.renderSelectedMainBlockBorderColor(isColor);
         this.renderSelectedBlockColor(isColor);
         var childLowerDepthBlockList = this.getBlockList_nodeBlockArea();
-        // console.log('childLowerDepthBlockList',childLowerDepthBlockList);
         childLowerDepthBlockList.forEach(block => {
             block.renderSelectedBlockColor(isColor);
         });
@@ -1877,17 +1867,15 @@ define([
                         if (!selectedBlock) {
                             /** 이동한 block이 rootblock일 경우 */
                             if ( thisBlock.getPrevBlock() == null ) {
-                                console.log('이동한 block이 rootblock일 경우');
+                                // console.log('이동한 block이 rootblock일 경우');
                                 if (blockContainerThis.getNodeBlockList().length == 1) {
-                                    // thisBlock.removeRootBlock();
                                     // console.log('이동한 block이 rootblock일 경우 1');
                                     $_blockNewMainDom.remove();
                                     thisBlock.setMovedBlockListOpacity(1);
                                     blockContainerThis.resetBlockList(thisBlock);
                                     return;
                                 } else {
-                                    console.log('이동한 block이 rootblock일 경우 2');
-                                    // console.log('nodeBlockList_asc', nodeBlockList_asc);
+                                    // console.log('이동한 block이 rootblock일 경우 2');
                                     
                                     var nodeBlock_last = nodeBlockList_asc[nodeBlockList_asc.length - 1];
                                     var lastBlock = nodeBlock_last.getLastBlock_from_nodeBlockArea();
@@ -1897,7 +1885,7 @@ define([
 
                             /** 이동한 block의 prevBlock이 rootblock일 경우 */
                             else if ( thisBlock.getPrevBlock().getUUID() == blockContainerThis.getRootBlock().getUUID() ) {
-                                console.log('이동한 block이 prevBlock이 rootblock일 경우');
+                                // console.log('이동한 block이 prevBlock이 rootblock일 경우');
                                 selectedBlock = blockContainerThis.getRootToLastBottomBlock();
                             } 
 
@@ -1905,7 +1893,7 @@ define([
                              * 이동한 block의 prevBlock이 rootblock이 아닐 경우 
                              */
                             else {
-                                console.log('이동한 block이 rootblock이 아닐 경우 이동한 block의 prevBlock이 rootblock이 아닐 경우');
+                                // console.log('이동한 block이 rootblock이 아닐 경우 이동한 block의 prevBlock이 rootblock이 아닐 경우');
                                 var lastBottomBlock = blockContainerThis.getRootToLastBottomBlock();
 
                                 /** 이동한 Block의 하위 블럭 중에, Board에 놓여 있는 맨 마지막 Block이 포함되어 있는 경우 */
@@ -2194,15 +2182,13 @@ define([
             return;
         } 
         var code = '';
-         /** text 블럭이 아닐 경우 */
+         /** node 블럭이 아닐 경우 */
         if  (thisBlock.getBlockType() != BLOCK_CODELINE_TYPE.NODE) {
             code = blockContainerThis.findNodeBlock(thisBlock).setCodeLineAndGet();
             code += STR_KEYWORD_NEW_LINE;
         }
         
-        // code += STR_KEYWORD_NEW_LINE;
         code += blockContainerThis.makeCode(thisBlock);
-        // console.log('code',code);
         /** validation 걸릴 때 */
         if (code.indexOf('BREAK_RUN') != -1) {
             return;
@@ -2284,28 +2270,21 @@ define([
 
     /** API List Block을 vpnote에 저장할 때 실행하는 메소드 */
     Block.prototype.setMetadata = function() {
-        // console.log('setMetadata');
-
         var blockUUID = this.getUUID();
         var blockContainerThis = this.getBlockContainerThis();
         var importPakage = this.getImportPakage();
-        // console.log('importPakage',importPakage);
 
         importPakage.generateCode(false, false);
         importPakage.metaGenerate();
 
         blockContainerThis.removeOptionDom(blockUUID);
         var generatedMetaData = importPakage.metadata;
-        // var pacakgeUUID = importPakage.uuid;
-        // console.log('pacakgeUUID',pacakgeUUID);
-        // funcID : "com_variables
         var funcID = '';
         if (generatedMetaData) {
             funcID = generatedMetaData['funcID'];
         } else if (importPakage.funcID == 'com_variables') {
             funcID = 'com_variables';
         }
-        console.log('funcID',funcID);
     
         vpContainer.loadOption(funcID, vpContainer.optionPageLoadCallback, generatedMetaData);
         this.state.metadata = generatedMetaData;
