@@ -9,20 +9,17 @@ define([
     , 'nbextensions/visualpython/src/common/vpMakeDom'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     
 ], function ( $, vpCommon, vpConst, sb, 
               vpFuncJS, libPandas, vpMakeDom,
-              api, config, constData, blockRenderer ) {
+              api, constData ) {
 
     const { VP_CLASS_STYLE_FLEX_COLUMN_CENTER } = constData;
 
     var MakeOptionButton_type2 = function(id, className, title ) {
         var sbOptionButtonType2 = new sb.StringBuilder();
         
-        /** plus button  `vp-apiblock-plus-button-${uuid} */
         sbOptionButtonType2.appendFormatLine("<div id='{0}' class='{1}'>", id, className);
         sbOptionButtonType2.appendFormatLine("<button class='{0}'>" , 'vp-block-long-plus-button');
         sbOptionButtonType2.appendFormatLine("{0}", title);                                                    
