@@ -9,13 +9,11 @@ define([
     , 'nbextensions/visualpython/src/common/vpMakeDom'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     
 ], function ( $, vpCommon, vpConst, sb, 
               vpFuncJS, libPandas, vpMakeDom,
-              api, config, constData, blockRenderer ) {
+              api, constData ) {
 
     const { VP_CLASS_STYLE_FLEX_COLUMN_CENTER } = constData;
 
