@@ -8,94 +8,29 @@ define([
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutHorizontalSimple'
 
     , '../../api.js'    
-    , '../../config.js'
+
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 
 ], function ( $, vpCommon, vpConst, sb, vpSuggestInputText, vpTableLayoutVerticalSimple, vpTableLayoutHorizontalSimple
 
               , api
-              , config
               , constData
-              , blockRenderer
               , baseComponent ) {
 
-    const { ChangeOldToNewState
-        , FindStateValue
-
-        , CreateOneArrayValueAndGet
+    const { CreateOneArrayValueAndGet
         , UpdateOneArrayValueAndGet
         , DeleteOneArrayValueAndGet
+    
+        , GenerateIfConditionList} = api;
 
-        , DestructureFromBlockArray
-
-        , MakeFirstCharToUpperCase
-        , MapTypeToName
-        , RemoveSomeBlockAndGetBlockList
-        , ShuffleArray
-        , GetImageUrl
-        , ControlToggleInput } = api;
-
-    const { PROCESS_MODE } = config;
-
-    const { RenderBlockMainDom
-            , RenderBlockLeftHolderDom
-            , RenderBlockMainInnerDom
-            , RenderBlockMainHeaderDom
-
-            , RenderOptionPageContainer
-            , RenderOptionPageContainerInner
-            , RenderOptionPageInnerDom
-            , RenderOptionPageName
-            , RenderOptionTitle
-
-            , RenderInParamContainer
-            , RenderInParamDom
-            , RenderDefParamDom
-            , RenderBottomOptionTitle
-            , RenderDefaultOrDetailButton
-            , RenderInputRequiredColor
-            , RenderSelectRequiredColor
-            , RenderDeleteButton
-            , RenderSmallPlusDeleteButton
-
-
-
-            , RenderDefaultImportDom
-            , RenderCustomImportDom
-            , RenderIfElifOrExceptContainer
-            , RenderDefParamOrIfElifConditionPlusButton
-            , RenderDefaultOrCustomImportContainer
-
-            , RenderRunBlockButton
-            , RenderDeleteBlockButton
-            , RenderFocusedPage
-            
-            , RenderDomContainer
-            , RenderPropertyDom
-
-
-            , RenderClassParentDom
-            , RenderCodeBlockInputRequired
-
-            , RenderHTMLDomColor
-
-            , GenerateClassInParamList
-            , GenerateDefInParamList
-            , GenerateReturnOutParamList
-            , GenerateIfConditionList
-            , GenerateForParam } = blockRenderer;
-
-    const { BLOCK_DIRECTION
-            , BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
+    const { BLOCK_CODELINE_TYPE
 
             , IF_BLOCK_CONDITION_TYPE
             , IF_BLOCK_SELECT_VALUE_ARG_TYPE
 
             , STR_COLON_SELECTED
-            , STR_NULL
+            , STR_EMPTY
             , STR_FOR
             , STR_INPUT
             , STR_SELECTED 
@@ -164,16 +99,16 @@ define([
             , MakeVpSuggestInputText_apiblock
             , MakeOptionInput } = baseComponent;
 
-    var InitIfBlockOption = function(thatBlock, optionPageSelector) {
-        var uuid = thatBlock.getUUID();
-        var blockContainerThis = thatBlock.getBlockContainerThis();
-        var ifConditionListState = thatBlock.getState(STATE_elifConditionList);  
+    var InitIfBlockOption = function(thisBlock, optionPageSelector) {
+        var uuid = thisBlock.getUUID();
+        var blockContainerThis = thisBlock.getBlockContainerThis();
+        var ifConditionListState = thisBlock.getState(STATE_elifConditionList);  
    
         /** --------------------------------- If Option 이벤트 함수 바인딩 ---------------------------------- */           
 
         /** if 변경 이벤트 함수 바인딩 */
         ifConditionListState.forEach( ( condition, index ) => {
-            var uuid = thatBlock.getUUID();
+            var uuid = thisBlock.getUUID();
             const { conditionType } = condition;
 
             // IF_BLOCK_CONDITION_TYPE
@@ -188,7 +123,7 @@ define([
                      
                      
                        
-                                var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
+                                var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
                                 var ifConditionState = ifConditionListState[index];
                                 var inputValue = $(this).val();
     
@@ -216,7 +151,7 @@ define([
                                         ...ifConditionState
                                         ,arg4: inputValue
                                     }
-                                    if (inputValue == 'none' || inputValue == STR_NULL) {
+                                    if (inputValue == 'none' || inputValue == STR_EMPTY) {
                                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                                         $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr("disabled", true);
@@ -239,12 +174,11 @@ define([
                                 }
     
                                 ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                                thatBlock.setState({
+                                thisBlock.setState({
                                     [STATE_elifConditionList]: ifConditionListState
                                 });
-                                var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                                $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                            
+                                var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.ELIF);
+                                thisBlock.writeCode(ifConditionCode);
                                 event.stopPropagation();
                             });
         
@@ -258,7 +192,7 @@ define([
          
                     // RenderInputRequiredColor(this);
            
-                    var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
+                    var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
                     var ifConditionState = ifConditionListState[index];
                     var inputValue = $(this).val();
 
@@ -269,12 +203,11 @@ define([
                
 
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         [STATE_elifConditionList]: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                
+                    var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.ELIF);
+                    thisBlock.writeCode(ifConditionCode);
                     event.stopPropagation();
                 });
 
@@ -284,7 +217,7 @@ define([
          
                     // RenderInputRequiredColor(this);
            
-                    var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
+                    var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
                     var ifConditionState = ifConditionListState[index];
                     var inputValue = $(this).val();
 
@@ -294,12 +227,11 @@ define([
                     }
 
                     ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-                    thatBlock.setState({
+                    thisBlock.setState({
                         [STATE_elifConditionList]: ifConditionListState
                     });
-                    var ifConditionCode = GenerateIfConditionList(thatBlock,BLOCK_CODELINE_TYPE.ELIF);
-                    $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-                
+                    var ifConditionCode = GenerateIfConditionList(thisBlock,BLOCK_CODELINE_TYPE.ELIF);
+                    thisBlock.writeCode(ifConditionCode);
                     event.stopPropagation();
                 });
             }
@@ -307,7 +239,7 @@ define([
             /** 삭제 if condition */
             $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid));
             $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_DELETE + index + uuid), function(event) {
-                var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
+                var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
 
                 if (ifConditionListState.length == 1) {
                     return;
@@ -315,12 +247,11 @@ define([
                 
                 ifConditionListState = DeleteOneArrayValueAndGet(ifConditionListState, index);
 
-                thatBlock.setState({
+                thisBlock.setState({
                     [STATE_elifConditionList]: ifConditionListState
                 });
-                var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-                $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-
+                var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+                thisBlock.writeCode(ifConditionCode);
                 blockContainerThis.renderBlockOptionTab();
 
                 event.stopPropagation();
@@ -331,25 +262,23 @@ define([
         $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid));
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid), function(event) {
 
-            var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
-            thatBlock.addVariableIndex();
-            // var variableIndex = thatBlock.getVariableIndex();
+            var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
+            thisBlock.addVariableIndex();
             var newCondition = {
                 arg1: ''
                 , arg2: ''
                 , arg3: ''
-                , arg4: 'none'
+                , arg4: ''
                 , arg5: ''
                 , arg6: ''
                 , conditionType: IF_BLOCK_CONDITION_TYPE.ARG
             }
             ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_elifConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-            
+            var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
             blockContainerThis.renderBlockOptionTab();
             event.stopPropagation();
         });
@@ -358,8 +287,8 @@ define([
         $(document).off(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid));
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid), function(event) {
 
-            var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
-            thatBlock.addVariableIndex();
+            var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
+            thisBlock.addVariableIndex();
         
             var newCondition = {
                 codeLine: ''
@@ -367,19 +296,18 @@ define([
                 , conditionType: IF_BLOCK_CONDITION_TYPE.USER_INPUT
             }
             ifConditionListState = CreateOneArrayValueAndGet(ifConditionListState, ifConditionListState.length, newCondition);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_elifConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-            
+            var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
             blockContainerThis.renderBlockOptionTab();
             event.stopPropagation();
         });
 
         /** arg1, arg2, arg3, arg4, arg5, arg6 select 변경 if condition */
         var bindSelectValueEventFunc_if = function(selectedValue, index, type) {
-            var ifConditionListState = thatBlock.getState(STATE_elifConditionList);
+            var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
             var ifConditionState = ifConditionListState[index];
             var updatedValue;
             if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1) {
@@ -426,42 +354,22 @@ define([
                     ...ifConditionState
                     , arg6: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, selectedValue);
             }
             ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_elifConditionList]: ifConditionListState
             });
-            var ifConditionCode = GenerateIfConditionList(thatBlock, BLOCK_CODELINE_TYPE.ELIF);
-            $(`.vp-block-header-${thatBlock.getUUID()}`).html(ifConditionCode);
-
-
-            // blockContainerThis.renderBlockOptionTab();
+            var ifConditionCode = GenerateIfConditionList(thisBlock, BLOCK_CODELINE_TYPE.ELIF);
+            thisBlock.writeCode(ifConditionCode);
         }
 
-        /** --------------------------------- Else Option 이벤트 함수 바인딩 ---------------------------------- */  
-        /** Else block 생성, 삭제 이벤트 함수 바인딩 */
-        // blockContainerThis.bindElseBlockEvent(thatBlock, BLOCK_CODELINE_TYPE.ELSE);
-
-
-
-
-
-
-
-
-
-
-
-
         /** If option 렌더링 */
         var renderThisComponent = function() {
-            var optionContainerDom = MakeOptionContainer();
+            var optionContainerDom = MakeOptionContainer(thisBlock);
             /* --------------------------- if ----------------------------- */
             var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
-            var variableIndex = thatBlock.getVariableIndex();
 
-            var ifConditionListState = thatBlock.getState(STATE_elifConditionList);   
+            var ifConditionListState = thisBlock.getState(STATE_elifConditionList);   
             ifConditionListState.forEach( (condition, index) => {
      
                 const { conditionType } = condition; 
@@ -623,7 +531,7 @@ define([
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).val(arg5);
                 // var isArg5Disabled = false;   
                 // isArg5Disabled = true;
-                if (arg4 == 'none' || arg4 == STR_NULL) {
+                if (arg4 == 'none' || arg4 == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
@@ -650,9 +558,11 @@ define([
 
                 // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
             });
+
+            return optionContainerDom;
         }
 
-        renderThisComponent();
+        return renderThisComponent();
     }
 
     return InitIfBlockOption;
