@@ -149,7 +149,7 @@ define([
 
         // load udf list to table 'vp_udfList'
         vpSetting.loadUserDefinedCodeList(function(udfList) {
-            console.log('udfList', udfList);
+            // console.log('udfList', udfList);
 
             // TEST: test list
             // udfList= [ {name: 'test1', code: 'codecode long code here hahahahahahahahaha example test one two three'}];
@@ -331,7 +331,6 @@ define([
         if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
-        sbCode.appendLine('# Auto-Generated by VisualPython - Common > User-defined Code');
         sbCode.append(this.vp_userCode.getValue());
 
         // save codemirror value to origin textarea
